package com.sun.java.swing.plaf.windows;

import javax.swing.UIManager;
import java.awt.Color;
import sun.swing.SwingUtilities2;
import java.awt.Graphics;
import javax.swing.JLabel;
import sun.awt.AppContext;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicLabelUI;

public class WindowsLabelUI extends BasicLabelUI
{
    private static final Object WINDOWS_LABEL_UI_KEY;
    
    public WindowsLabelUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        AppContext appContext = AppContext.getAppContext();
        WindowsLabelUI value = (WindowsLabelUI)appContext.get(WindowsLabelUI.WINDOWS_LABEL_UI_KEY);
        if (value == null) {
            value = new WindowsLabelUI();
            appContext.put(WindowsLabelUI.WINDOWS_LABEL_UI_KEY, value);
            return value;
        }
        return value;
    }
    
    @Override
    protected void paintEnabledText(JLabel c, Graphics g, String text, int x, int y) {
        int displayedMnemonicIndex = c.getDisplayedMnemonicIndex();
        if (WindowsLookAndFeel.isMnemonicHidden()) {
            displayedMnemonicIndex = -1;
        }
        g.setColor(c.getForeground());
        SwingUtilities2.drawStringUnderlineCharAt(c, g, text, displayedMnemonicIndex, x, y);
    }
    
    @Override
    protected void paintDisabledText(JLabel label, Graphics graphics, String s, int n, int n2) {
        int displayedMnemonicIndex = label.getDisplayedMnemonicIndex();
        if (WindowsLookAndFeel.isMnemonicHidden()) {
            displayedMnemonicIndex = -1;
        }
        if (UIManager.getColor("Label.disabledForeground") instanceof Color && UIManager.getColor("Label.disabledShadow") instanceof Color) {
            graphics.setColor(UIManager.getColor("Label.disabledShadow"));
            SwingUtilities2.drawStringUnderlineCharAt(label, graphics, s, displayedMnemonicIndex, n + 1, n2 + 1);
            graphics.setColor(UIManager.getColor("Label.disabledForeground"));
            SwingUtilities2.drawStringUnderlineCharAt(label, graphics, s, displayedMnemonicIndex, n, n2);
        }
        else {
            Color background = label.getBackground();
            graphics.setColor(background.brighter());
            SwingUtilities2.drawStringUnderlineCharAt(label, graphics, s, displayedMnemonicIndex, n + 1, n2 + 1);
            graphics.setColor(background.darker());
            SwingUtilities2.drawStringUnderlineCharAt(label, graphics, s, displayedMnemonicIndex, n, n2);
        }
    }
    
    static {
        WINDOWS_LABEL_UI_KEY = new Object();
    }
}
